summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/tools
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
commitb6c6d9f8dd1221e5d9dc5b674e93797761470024 (patch)
tree94563ba51148e9fd71f5c8df86439c84945d5d81 /experimental/tqtinterface/qt4/src/tools
parent03256f3cd5149f3ff5f5f45765b0b0659db4e036 (diff)
downloadtde-b6c6d9f8dd1221e5d9dc5b674e93797761470024.tar.gz
tde-b6c6d9f8dd1221e5d9dc5b674e93797761470024.zip
rename the following methods:
tqparent parent tqmask mask
Diffstat (limited to 'experimental/tqtinterface/qt4/src/tools')
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqdir.cpp8
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqfileinfo_unix.cpp30
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqmap.cpp142
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqmap.h60
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqregexp.cpp30
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqtextstream.cpp8
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqtextstream.h6
7 files changed, 142 insertions, 142 deletions
diff --git a/experimental/tqtinterface/qt4/src/tools/tqdir.cpp b/experimental/tqtinterface/qt4/src/tools/tqdir.cpp
index 99c9094e8..311a44dd1 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqdir.cpp
+++ b/experimental/tqtinterface/qt4/src/tools/tqdir.cpp
@@ -601,19 +601,19 @@ void TQDir::setNameFilter( const TQString &nameFilter )
systems that don't support symbolic links).
\value All List directories, files, drives and symlinks (this does not list
broken symlinks unless you specify System).
- \value TypeMask A tqmask for the the Dirs, Files, Drives and
+ \value TypeMask A mask for the the Dirs, Files, Drives and
NoSymLinks flags.
\value Readable List files for which the application has read access.
\value Writable List files for which the application has write access.
\value Executable List files for which the application has execute
access. Executables needs to be combined with Dirs or Files.
- \value RWEMask A tqmask for the Readable, Writable and Executable flags.
+ \value RWEMask A mask for the Readable, Writable and Executable flags.
\value Modified Only list files that have been modified (ignored
under Unix).
\value Hidden List hidden files (on Unix, files starting with a .).
\value System List system files (on Unix, FIFOs, sockets and
tqdevice files)
- \value AccessMask A tqmask for the Readable, Writable, Executable
+ \value AccessMask A mask for the Readable, Writable, Executable
Modified, Hidden and System flags
\value DefaultFilter Internal flag.
@@ -665,7 +665,7 @@ void TQDir::setFilter( int filterSpec )
\value Time Sort by time (modification time).
\value Size Sort by file size.
\value Unsorted Do not sort.
- \value SortByMask A tqmask for Name, Time and Size.
+ \value SortByMask A mask for Name, Time and Size.
\value DirsFirst Put the directories first, then the files.
\value Reversed Reverse the sort order.
diff --git a/experimental/tqtinterface/qt4/src/tools/tqfileinfo_unix.cpp b/experimental/tqtinterface/qt4/src/tools/tqfileinfo_unix.cpp
index 4a0891699..dcde72ab4 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqfileinfo_unix.cpp
+++ b/experimental/tqtinterface/qt4/src/tools/tqfileinfo_unix.cpp
@@ -290,33 +290,33 @@ bool TQFileInfo::permission( int permissionSpec ) const
if ( !fic || !cache )
doStat();
if ( fic ) {
- uint tqmask = 0;
+ uint mask = 0;
if ( permissionSpec & ReadOwner )
- tqmask |= S_IRUSR;
+ mask |= S_IRUSR;
if ( permissionSpec & WriteOwner )
- tqmask |= S_IWUSR;
+ mask |= S_IWUSR;
if ( permissionSpec & ExeOwner )
- tqmask |= S_IXUSR;
+ mask |= S_IXUSR;
if ( permissionSpec & ReadUser )
- tqmask |= S_IRUSR;
+ mask |= S_IRUSR;
if ( permissionSpec & WriteUser )
- tqmask |= S_IWUSR;
+ mask |= S_IWUSR;
if ( permissionSpec & ExeUser )
- tqmask |= S_IXUSR;
+ mask |= S_IXUSR;
if ( permissionSpec & ReadGroup )
- tqmask |= S_IRGRP;
+ mask |= S_IRGRP;
if ( permissionSpec & WriteGroup )
- tqmask |= S_IWGRP;
+ mask |= S_IWGRP;
if ( permissionSpec & ExeGroup )
- tqmask |= S_IXGRP;
+ mask |= S_IXGRP;
if ( permissionSpec & ReadOther )
- tqmask |= S_IROTH;
+ mask |= S_IROTH;
if ( permissionSpec & WriteOther )
- tqmask |= S_IWOTH;
+ mask |= S_IWOTH;
if ( permissionSpec & ExeOther )
- tqmask |= S_IXOTH;
- if ( tqmask ) {
- return (fic->st.st_mode & tqmask) == tqmask;
+ mask |= S_IXOTH;
+ if ( mask ) {
+ return (fic->st.st_mode & mask) == mask;
} else {
#if defined(TQT_CHECK_NULL)
qWarning( "TQFileInfo::permission: permissionSpec is 0" );
diff --git a/experimental/tqtinterface/qt4/src/tools/tqmap.cpp b/experimental/tqtinterface/qt4/src/tools/tqmap.cpp
index 70d63423e..e58145536 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqmap.cpp
+++ b/experimental/tqtinterface/qt4/src/tools/tqmap.cpp
@@ -49,16 +49,16 @@ void TQMapPrivateBase::rotateLeft( NodePtr x, NodePtr& root)
NodePtr y = x->right;
x->right = y->left;
if (y->left !=0)
- y->left->tqparent = x;
- y->tqparent = x->tqparent;
+ y->left->parent = x;
+ y->parent = x->parent;
if (x == root)
root = y;
- else if (x == x->tqparent->left)
- x->tqparent->left = y;
+ else if (x == x->parent->left)
+ x->parent->left = y;
else
- x->tqparent->right = y;
+ x->parent->right = y;
y->left = x;
- x->tqparent = y;
+ x->parent = y;
}
@@ -67,54 +67,54 @@ void TQMapPrivateBase::rotateRight( NodePtr x, NodePtr& root )
NodePtr y = x->left;
x->left = y->right;
if (y->right != 0)
- y->right->tqparent = x;
- y->tqparent = x->tqparent;
+ y->right->parent = x;
+ y->parent = x->parent;
if (x == root)
root = y;
- else if (x == x->tqparent->right)
- x->tqparent->right = y;
+ else if (x == x->parent->right)
+ x->parent->right = y;
else
- x->tqparent->left = y;
+ x->parent->left = y;
y->right = x;
- x->tqparent = y;
+ x->parent = y;
}
void TQMapPrivateBase::rebalance( NodePtr x, NodePtr& root)
{
x->color = Node::Red;
- while ( x != root && x->tqparent->color == Node::Red ) {
- if ( x->tqparent == x->tqparent->tqparent->left ) {
- NodePtr y = x->tqparent->tqparent->right;
+ while ( x != root && x->parent->color == Node::Red ) {
+ if ( x->parent == x->parent->parent->left ) {
+ NodePtr y = x->parent->parent->right;
if (y && y->color == Node::Red) {
- x->tqparent->color = Node::Black;
+ x->parent->color = Node::Black;
y->color = Node::Black;
- x->tqparent->tqparent->color = Node::Red;
- x = x->tqparent->tqparent;
+ x->parent->parent->color = Node::Red;
+ x = x->parent->parent;
} else {
- if (x == x->tqparent->right) {
- x = x->tqparent;
+ if (x == x->parent->right) {
+ x = x->parent;
rotateLeft( x, root );
}
- x->tqparent->color = Node::Black;
- x->tqparent->tqparent->color = Node::Red;
- rotateRight (x->tqparent->tqparent, root );
+ x->parent->color = Node::Black;
+ x->parent->parent->color = Node::Red;
+ rotateRight (x->parent->parent, root );
}
} else {
- NodePtr y = x->tqparent->tqparent->left;
+ NodePtr y = x->parent->parent->left;
if ( y && y->color == Node::Red ) {
- x->tqparent->color = Node::Black;
+ x->parent->color = Node::Black;
y->color = Node::Black;
- x->tqparent->tqparent->color = Node::Red;
- x = x->tqparent->tqparent;
+ x->parent->parent->color = Node::Red;
+ x = x->parent->parent;
} else {
- if (x == x->tqparent->left) {
- x = x->tqparent;
+ if (x == x->parent->left) {
+ x = x->parent;
rotateRight( x, root );
}
- x->tqparent->color = Node::Black;
- x->tqparent->tqparent->color = Node::Red;
- rotateLeft( x->tqparent->tqparent, root );
+ x->parent->color = Node::Black;
+ x->parent->parent->color = Node::Red;
+ rotateLeft( x->parent->parent, root );
}
}
}
@@ -128,7 +128,7 @@ NodePtr TQMapPrivateBase::removeAndRebalance( NodePtr z, NodePtr& root,
{
NodePtr y = z;
NodePtr x;
- NodePtr x_tqparent;
+ NodePtr x_parent;
if (y->left == 0) {
x = y->right;
} else {
@@ -143,109 +143,109 @@ NodePtr TQMapPrivateBase::removeAndRebalance( NodePtr z, NodePtr& root,
}
}
if (y != z) {
- z->left->tqparent = y;
+ z->left->parent = y;
y->left = z->left;
if (y != z->right) {
- x_tqparent = y->tqparent;
+ x_parent = y->parent;
if (x)
- x->tqparent = y->tqparent;
- y->tqparent->left = x;
+ x->parent = y->parent;
+ y->parent->left = x;
y->right = z->right;
- z->right->tqparent = y;
+ z->right->parent = y;
} else {
- x_tqparent = y;
+ x_parent = y;
}
if (root == z)
root = y;
- else if (z->tqparent->left == z)
- z->tqparent->left = y;
+ else if (z->parent->left == z)
+ z->parent->left = y;
else
- z->tqparent->right = y;
- y->tqparent = z->tqparent;
+ z->parent->right = y;
+ y->parent = z->parent;
// Swap the colors
Node::Color c = y->color;
y->color = z->color;
z->color = c;
y = z;
} else {
- x_tqparent = y->tqparent;
+ x_parent = y->parent;
if (x)
- x->tqparent = y->tqparent;
+ x->parent = y->parent;
if (root == z)
root = x;
- else if (z->tqparent->left == z)
- z->tqparent->left = x;
+ else if (z->parent->left == z)
+ z->parent->left = x;
else
- z->tqparent->right = x;
+ z->parent->right = x;
if ( leftmost == z ) {
if (z->right == 0)
- leftmost = z->tqparent;
+ leftmost = z->parent;
else
leftmost = x->minimum();
}
if (rightmost == z) {
if (z->left == 0)
- rightmost = z->tqparent;
+ rightmost = z->parent;
else
rightmost = x->maximum();
}
}
if (y->color != Node::Red) {
while (x != root && (x == 0 || x->color == Node::Black)) {
- if (x == x_tqparent->left) {
- NodePtr w = x_tqparent->right;
+ if (x == x_parent->left) {
+ NodePtr w = x_parent->right;
if (w->color == Node::Red) {
w->color = Node::Black;
- x_tqparent->color = Node::Red;
- rotateLeft(x_tqparent, root);
- w = x_tqparent->right;
+ x_parent->color = Node::Red;
+ rotateLeft(x_parent, root);
+ w = x_parent->right;
}
if ((w->left == 0 || w->left->color == Node::Black) &&
(w->right == 0 || w->right->color == Node::Black)) {
w->color = Node::Red;
- x = x_tqparent;
- x_tqparent = x_tqparent->tqparent;
+ x = x_parent;
+ x_parent = x_parent->parent;
} else {
if (w->right == 0 || w->right->color == Node::Black) {
if (w->left)
w->left->color = Node::Black;
w->color = Node::Red;
rotateRight(w, root);
- w = x_tqparent->right;
+ w = x_parent->right;
}
- w->color = x_tqparent->color;
- x_tqparent->color = Node::Black;
+ w->color = x_parent->color;
+ x_parent->color = Node::Black;
if (w->right)
w->right->color = Node::Black;
- rotateLeft(x_tqparent, root);
+ rotateLeft(x_parent, root);
break;
}
} else {
- NodePtr w = x_tqparent->left;
+ NodePtr w = x_parent->left;
if (w->color == Node::Red) {
w->color = Node::Black;
- x_tqparent->color = Node::Red;
- rotateRight(x_tqparent, root);
- w = x_tqparent->left;
+ x_parent->color = Node::Red;
+ rotateRight(x_parent, root);
+ w = x_parent->left;
}
if ((w->right == 0 || w->right->color == Node::Black) &&
(w->left == 0 || w->left->color == Node::Black)) {
w->color = Node::Red;
- x = x_tqparent;
- x_tqparent = x_tqparent->tqparent;
+ x = x_parent;
+ x_parent = x_parent->parent;
} else {
if (w->left == 0 || w->left->color == Node::Black) {
if (w->right)
w->right->color = Node::Black;
w->color = Node::Red;
rotateLeft(w, root);
- w = x_tqparent->left;
+ w = x_parent->left;
}
- w->color = x_tqparent->color;
- x_tqparent->color = Node::Black;
+ w->color = x_parent->color;
+ x_parent->color = Node::Black;
if (w->left)
w->left->color = Node::Black;
- rotateRight(x_tqparent, root);
+ rotateRight(x_parent, root);
break;
}
}
diff --git a/experimental/tqtinterface/qt4/src/tools/tqmap.h b/experimental/tqtinterface/qt4/src/tools/tqmap.h
index 006f49037..cb280fcc9 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqmap.h
+++ b/experimental/tqtinterface/qt4/src/tools/tqmap.h
@@ -71,7 +71,7 @@ struct TQ_EXPORT TQMapNodeBase
TQMapNodeBase* left;
TQMapNodeBase* right;
- TQMapNodeBase* tqparent;
+ TQMapNodeBase* parent;
Color color;
@@ -183,10 +183,10 @@ TQ_INLINE_TEMPLATES int TQMapIterator<K,T>::inc()
while ( tmp->left )
tmp = tmp->left;
} else {
- TQMapNodeBase* y = tmp->tqparent;
+ TQMapNodeBase* y = tmp->parent;
while (tmp == y->right) {
tmp = y;
- y = y->tqparent;
+ y = y->parent;
}
if (tmp->right != y)
tmp = y;
@@ -200,7 +200,7 @@ TQ_INLINE_TEMPLATES int TQMapIterator<K,T>::dec()
{
TQMapNodeBase* tmp = node;
if (tmp->color == TQMapNodeBase::Red &&
- tmp->tqparent->tqparent == tmp ) {
+ tmp->parent->parent == tmp ) {
tmp = tmp->right;
} else if (tmp->left != 0) {
TQMapNodeBase* y = tmp->left;
@@ -208,10 +208,10 @@ TQ_INLINE_TEMPLATES int TQMapIterator<K,T>::dec()
y = y->right;
tmp = y;
} else {
- TQMapNodeBase* y = tmp->tqparent;
+ TQMapNodeBase* y = tmp->parent;
while (tmp == y->left) {
tmp = y;
- y = y->tqparent;
+ y = y->parent;
}
tmp = y;
}
@@ -299,10 +299,10 @@ TQ_INLINE_TEMPLATES int TQMapConstIterator<K,T>::inc()
while ( tmp->left )
tmp = tmp->left;
} else {
- TQMapNodeBase* y = tmp->tqparent;
+ TQMapNodeBase* y = tmp->parent;
while (tmp == y->right) {
tmp = y;
- y = y->tqparent;
+ y = y->parent;
}
if (tmp->right != y)
tmp = y;
@@ -316,7 +316,7 @@ TQ_INLINE_TEMPLATES int TQMapConstIterator<K,T>::dec()
{
TQMapNodeBase* tmp = node;
if (tmp->color == TQMapNodeBase::Red &&
- tmp->tqparent->tqparent == tmp ) {
+ tmp->parent->parent == tmp ) {
tmp = tmp->right;
} else if (tmp->left != 0) {
TQMapNodeBase* y = tmp->left;
@@ -324,10 +324,10 @@ TQ_INLINE_TEMPLATES int TQMapConstIterator<K,T>::dec()
y = y->right;
tmp = y;
} else {
- TQMapNodeBase* y = tmp->tqparent;
+ TQMapNodeBase* y = tmp->parent;
while (tmp == y->left) {
tmp = y;
- y = y->tqparent;
+ y = y->parent;
}
tmp = y;
}
@@ -394,7 +394,7 @@ public:
ConstIterator find(const Key& k) const;
void remove( Iterator it ) {
- NodePtr del = (NodePtr) removeAndRebalance( it.node, header->tqparent, header->left, header->right );
+ NodePtr del = (NodePtr) removeAndRebalance( it.node, header->parent, header->left, header->right );
delete del;
--node_count;
}
@@ -402,7 +402,7 @@ public:
#ifdef TQT_TQMAP_DEBUG
void inorder( TQMapNodeBase* x = 0, int level = 0 ){
if ( !x )
- x = header->tqparent;
+ x = header->parent;
if ( x->left )
inorder( x->left, level + 1 );
//cout << level << " Key=" << key(x) << " Value=" << ((NodePtr)x)->data << endl;
@@ -414,7 +414,7 @@ public:
#if 0
Iterator insertMulti(const Key& v){
TQMapNodeBase* y = header;
- TQMapNodeBase* x = header->tqparent;
+ TQMapNodeBase* x = header->parent;
while (x != 0){
y = x;
x = ( v < key(x) ) ? x->left : x->right;
@@ -443,21 +443,21 @@ template <class Key, class T>
TQ_INLINE_TEMPLATES TQMapPrivate<Key,T>::TQMapPrivate() {
header = new Node;
header->color = TQMapNodeBase::Red; // Mark the header
- header->tqparent = 0;
+ header->parent = 0;
header->left = header->right = header;
}
template <class Key, class T>
TQ_INLINE_TEMPLATES TQMapPrivate<Key,T>::TQMapPrivate( const TQMapPrivate< Key, T >* _map ) : TQMapPrivateBase( _map ) {
header = new Node;
header->color = TQMapNodeBase::Red; // Mark the header
- if ( _map->header->tqparent == 0 ) {
- header->tqparent = 0;
+ if ( _map->header->parent == 0 ) {
+ header->parent = 0;
header->left = header->right = header;
} else {
- header->tqparent = copy( (NodePtr)(_map->header->tqparent) );
- header->tqparent->tqparent = header;
- header->left = header->tqparent->minimum();
- header->right = header->tqparent->maximum();
+ header->parent = copy( (NodePtr)(_map->header->parent) );
+ header->parent->parent = header;
+ header->left = header->parent->minimum();
+ header->right = header->parent->maximum();
}
}
@@ -470,13 +470,13 @@ TQ_INLINE_TEMPLATES TQ_TYPENAME TQMapPrivate<Key,T>::NodePtr TQMapPrivate<Key,T>
n->color = p->color;
if ( p->left ) {
n->left = copy( (NodePtr)(p->left) );
- n->left->tqparent = n;
+ n->left->parent = n;
} else {
n->left = 0;
}
if ( p->right ) {
n->right = copy( (NodePtr)(p->right) );
- n->right->tqparent = n;
+ n->right->parent = n;
} else {
n->right = 0;
}
@@ -486,9 +486,9 @@ TQ_INLINE_TEMPLATES TQ_TYPENAME TQMapPrivate<Key,T>::NodePtr TQMapPrivate<Key,T>
template <class Key, class T>
TQ_INLINE_TEMPLATES void TQMapPrivate<Key,T>::clear()
{
- clear( (NodePtr)(header->tqparent) );
+ clear( (NodePtr)(header->parent) );
header->color = TQMapNodeBase::Red;
- header->tqparent = 0;
+ header->parent = 0;
header->left = header->right = header;
node_count = 0;
}
@@ -508,7 +508,7 @@ template <class Key, class T>
TQ_INLINE_TEMPLATES TQ_TYPENAME TQMapPrivate<Key,T>::ConstIterator TQMapPrivate<Key,T>::find(const Key& k) const
{
TQMapNodeBase* y = header; // Last node
- TQMapNodeBase* x = header->tqparent; // Root node.
+ TQMapNodeBase* x = header->parent; // Root node.
while ( x != 0 ) {
// If as k <= key(x) go left
@@ -532,7 +532,7 @@ TQ_INLINE_TEMPLATES TQ_TYPENAME TQMapPrivate<Key,T>::Iterator TQMapPrivate<Key,T
{
// Search correct position in the tree
TQMapNodeBase* y = header;
- TQMapNodeBase* x = header->tqparent;
+ TQMapNodeBase* x = header->parent;
bool result = TRUE;
while ( x != 0 ) {
result = ( k < key(x) );
@@ -565,7 +565,7 @@ TQ_INLINE_TEMPLATES TQ_TYPENAME TQMapPrivate<Key,T>::Iterator TQMapPrivate<Key,T
if (y == header || x != 0 || k < key(y) ) {
y->left = z; // also makes leftmost = z when y == header
if ( y == header ) {
- header->tqparent = z;
+ header->parent = z;
header->right = z;
} else if ( y == header->left )
header->left = z; // maintain leftmost pointing to min node
@@ -574,10 +574,10 @@ TQ_INLINE_TEMPLATES TQ_TYPENAME TQMapPrivate<Key,T>::Iterator TQMapPrivate<Key,T
if ( y == header->right )
header->right = z; // maintain rightmost pointing to max node
}
- z->tqparent = y;
+ z->parent = y;
z->left = 0;
z->right = 0;
- rebalance( z, header->tqparent );
+ rebalance( z, header->parent );
++node_count;
return Iterator(z);
}
diff --git a/experimental/tqtinterface/qt4/src/tools/tqtextstream.cpp b/experimental/tqtinterface/qt4/src/tools/tqtextstream.cpp
index 1225f7bf1..ca4b11e07 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqtextstream.cpp
+++ b/experimental/tqtinterface/qt4/src/tools/tqtextstream.cpp
@@ -2310,14 +2310,14 @@ TQTextStream &TQTextStream::operator<<( void *ptr )
*/
/*!
- \fn int TQTextStream::setf( int bits, int tqmask )
+ \fn int TQTextStream::setf( int bits, int mask )
\overload
- Sets the stream flag bits \a bits with a bit tqmask \a tqmask. Returns
+ Sets the stream flag bits \a bits with a bit mask \a mask. Returns
the previous stream flags.
- Equivalent to \c{flags( (flags() & ~tqmask) | (bits & tqmask) )}.
+ Equivalent to \c{flags( (flags() & ~mask) | (bits & mask) )}.
\sa setf(), unsetf()
*/
@@ -2328,7 +2328,7 @@ TQTextStream &TQTextStream::operator<<( void *ptr )
Clears the stream flag bits \a bits. Returns the previous stream
flags.
- Equivalent to \c{flags( flags() & ~tqmask )}.
+ Equivalent to \c{flags( flags() & ~mask )}.
\sa setf()
*/
diff --git a/experimental/tqtinterface/qt4/src/tools/tqtextstream.h b/experimental/tqtinterface/qt4/src/tools/tqtextstream.h
index 53aaddb56..684687b32 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqtextstream.h
+++ b/experimental/tqtinterface/qt4/src/tools/tqtextstream.h
@@ -142,7 +142,7 @@ public:
int flags() const;
int flags( int f );
int setf( int bits );
- int setf( int bits, int tqmask );
+ int setf( int bits, int mask );
int unsetf( int bits );
void reset();
@@ -257,8 +257,8 @@ inline int TQTextStream::flags( int f )
inline int TQTextStream::setf( int bits )
{ int oldf = fflags; fflags |= bits; return oldf; }
-inline int TQTextStream::setf( int bits, int tqmask )
-{ int oldf = fflags; fflags = (fflags & ~tqmask) | (bits & tqmask); return oldf; }
+inline int TQTextStream::setf( int bits, int mask )
+{ int oldf = fflags; fflags = (fflags & ~mask) | (bits & mask); return oldf; }
inline int TQTextStream::unsetf( int bits )
{ int oldf = fflags; fflags &= ~bits; return oldf; }
diff --git a/experimental/tqtinterface/qt4/src/tools/tqregexp.cpp b/experimental/tqtinterface/qt4/src/tools/tqregexp.cpp
index 5f738723d..7a7f1abed 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqregexp.cpp
+++ b/experimental/tqtinterface/qt4/src/tools/tqregexp.cpp
@@ -1074,7 +1074,7 @@ private:
*/
struct Atom
{
- int tqparent; // index of tqparent in array of atoms
+ int parent; // index of parent in array of atoms
int capture; // index of capture, from 1 to ncap
};
#endif
@@ -1111,7 +1111,7 @@ private:
( (Anchor_FirstLookahead << MaxLookaheads) - 1 ) };
#ifndef TQT_NO_REGEXP_CAPTURE
int startAtom( bool capture );
- void finishAtom( int atom ) { cf = f[atom].tqparent; }
+ void finishAtom( int atom ) { cf = f[atom].parent; }
#endif
#ifndef TQT_NO_REGEXP_LOOKAHEAD
@@ -1605,7 +1605,7 @@ void TQRegExpEngine::dump() const
if ( nf > 0 ) {
qDebug( " Atom Parent Capture" );
for ( i = 0; i < nf; i++ )
- qDebug( " %6d %6d %6d", i, f[i].tqparent, f[i].capture );
+ qDebug( " %6d %6d %6d", i, f[i].parent, f[i].capture );
}
#endif
#ifndef TQT_NO_REGEXP_ANCHOR_ALT
@@ -1672,7 +1672,7 @@ int TQRegExpEngine::startAtom( bool capture )
{
if ( (nf & (nf + 1)) == 0 && nf + 1 >= (int) f.size() )
f.resize( (nf + 1) << 1 );
- f[nf].tqparent = cf;
+ f[nf].parent = cf;
cf = nf++;
f[cf].capture = capture ? ncap++ : -1;
return cf;
@@ -2059,11 +2059,11 @@ bool TQRegExpEngine::matchHere()
/*
Lemma 1. For any x in the range [0..nf), we
- have f[x].tqparent < x.
+ have f[x].parent < x.
Proof. By looking at startAtom(), it is
clear that cf < nf holds all the time, and
- thus that f[nf].tqparent < nf.
+ thus that f[nf].parent < nf.
*/
/*
@@ -2076,7 +2076,7 @@ bool TQRegExpEngine::matchHere()
b.fill( FALSE, nf );
b.setBit( q, TRUE );
for ( int ell = q + 1; ell < nf; ell++ ) {
- if ( b.testBit(f[ell].tqparent) ) {
+ if ( b.testBit(f[ell].parent) ) {
b.setBit( ell, TRUE );
cap = f[ell].capture;
if ( cap >= 0 ) {
@@ -2085,15 +2085,15 @@ bool TQRegExpEngine::matchHere()
}
}
}
- p = f[q].tqparent;
+ p = f[q].parent;
/*
Otherwise, close the capture zones we are
leaving. We are leaving f[c].capture,
- f[f[c].tqparent].capture,
- f[f[f[c].tqparent].tqparent].capture, ...,
+ f[f[c].parent].capture,
+ f[f[f[c].parent].parent].capture, ...,
until f[x].capture, with x such that
- f[x].tqparent is the youngest common ancestor
+ f[x].parent is the youngest common ancestor
for c and n.
We go up along c's and n's ancestry until
@@ -2113,9 +2113,9 @@ bool TQRegExpEngine::matchHere()
capEnd[cap] = i;
}
}
- p = f[p].tqparent;
+ p = f[p].parent;
} else {
- q = f[q].tqparent;
+ q = f[q].parent;
}
}
}
@@ -2123,7 +2123,7 @@ bool TQRegExpEngine::matchHere()
/*
In any case, we now open the capture zones
we are entering. We work upwards from n
- until we reach p (the tqparent of the atom we
+ until we reach p (the parent of the atom we
reenter or the youngest common ancestor).
*/
while ( n > p ) {
@@ -2132,7 +2132,7 @@ bool TQRegExpEngine::matchHere()
capBegin[cap] = i;
capEnd[cap] = EmptyCapture;
}
- n = f[n].tqparent;
+ n = f[n].parent;
}
/*
If the next state was already in